@@ -1,3 +1,5 @@
+//! Events related on the keyboard.
+
 use key_code::KeyCode;
 use key_mod::KeyMod;
 use scan_code::ScanCode;
@@ -8,11 +10,15 @@ pub mod key_code;
 pub mod key_mod;
 pub mod scan_code;
 
+/// A symbol on the keyboard with the modification and the relationship of actual and virtual key code.
 #[derive(Debug, Clone)]
 pub struct KeySymbol {
-    scan_code: ScanCode,
-    key_code: KeyCode,
-    key_mod: KeyMod,
+    /// The actual key code on the keyboard.
+    pub scan_code: ScanCode,
+    /// The virtual key code on the keyboard.
+    pub key_code: KeyCode,
+    /// The key modification on the keyboard.
+    pub key_mod: KeyMod,
 }
 
 impl From<bind::SDL_Keysym> for KeySymbol {
@@ -25,12 +31,18 @@ impl From<bind::SDL_Keysym> for KeySymbol {
     }
 }
 
+/// An event on interacting to the keyboard.
 #[derive(Debug, Clone)]
 pub struct KeyboardEvent {
+    /// When this event occurred.
     pub timestamp: u32,
+    /// The id of the window focused.
     pub window_id: u32,
+    /// Whether the key of symbol is pressed.
     pub is_pressed: bool,
+    /// Whether the key of symbol is repeated.
     pub is_repeated: bool,
+    /// The pressed/released symbol.
     pub symbol: KeySymbol,
 }
 
